@@ -17,7 +17,7 @@ from openlab import logger as openlabLogger # RENAME
 from openlab import results, setpoints
 
 # One logger for all http_clients
-logger = openlabLogger.makeLogger("openlab.http_client")
+openlab_logger = openlabLogger.makeLogger("openlab.http_client")
 
 class http_client(object):
     sim = None
@@ -30,7 +30,7 @@ class http_client(object):
         # Setup root to coordinate log formats        
         openlabLogger.setUpRootLog()
         
-        logger.info("Initializing Openlab http client")
+        openlab_logger.info("Initializing Openlab http client")
         
         #create and validate the oauth client
         self.client= login.create_token(**kwargs) # returns an oauth session
@@ -52,10 +52,10 @@ class http_client(object):
             version = pkg_resources.get_distribution("openlab").version
             is_outdated, latest_version = outdated.check_outdated('openlab', version)
             if is_outdated:
-                logger.warning(f"Your openlab version {version} is outdated. Consider upgrading to {latest_version}")
+                openlab_logger.warning(f"Your openlab version {version} is outdated. Consider upgrading to {latest_version}")
         except:
             # Don't want version check to crash/affect client
-            logger.info("Could not verify openlab is current")
+            openlab_logger.info("Could not verify openlab is current")
             
         return
 
@@ -67,13 +67,13 @@ class http_client(object):
             r.raise_for_status()
 
             if r.status_code != 200:
-                logger.error(f"Call to whoami failed with HTTP Code: {r.status_code}. Attempting to create new token")
+                openlab_logger.error(f"Call to whoami failed with HTTP Code: {r.status_code}. Attempting to create new token")
                 self.client = login.create_token()
             else:
-                logger.info("Login Succesfull")
+                openlab_logger.info("Login Succesfull")
 
         except InvalidGrantError:
-            logger.error("Invalid Grant Exception Thrown. Attempting to create new token")
+            openlab_logger.error("Invalid Grant Exception Thrown. Attempting to create new token")
             self.client = login.create_token()
         return 
 
@@ -97,7 +97,7 @@ class http_client(object):
            
             if status_code == success_status_code:
                 if success_msg is not None:
-                    logger.info(success_msg)
+                    openlab_logger.info(success_msg)
                 
                 method = response.request.method
                 # no content will throw jsonDecodeError
@@ -160,7 +160,7 @@ class http_client(object):
             query['licenseId'] = self.credentials['license_id']
             r = self.client.get(self.url + "/users/limits?", params = query)
         else:
-            logger.info("No license given. Defaulting to personal license")
+            openlab_logger.info("No license given. Defaulting to personal license")
             r = self.client.get(self.url + "/users/limits")
         return self.standard_response(r,200)
 
@@ -176,7 +176,7 @@ class http_client(object):
         """
         Deprecated: Use _check_if_simulation_exists() instead
         """
-        logger.warning("check_if_simulation_exists is Deprected. Use _check_if_simulation_exists instead")
+        openlab_logger.warning("check_if_simulation_exists is Deprected. Use _check_if_simulation_exists instead")
         return self._check_if_simulation_exists(sim_id)
 
     def _check_if_simulation_exists(self,sim_id):
@@ -311,7 +311,7 @@ class http_client(object):
         """
         Deprecated: Use _check_if_configuration_id_exists() instead
         """
-        logger.warning("check_if_configuration_id_exists is Deprected. Use _check_if_configuration_id_exists instead")
+        openlab_logger.warning("check_if_configuration_id_exists is Deprected. Use _check_if_configuration_id_exists instead")
         return self._check_if_configuration_id_exists(config_id)
 
     def _check_if_configuration_id_exists(self,config_id):
@@ -329,7 +329,7 @@ class http_client(object):
         """
         Deprecated: Use _check_if_configuration_name_exists() instead
         """
-        logger.warning("check_if_configuration_name_exists is Deprected. Use _check_if_configuration_name_exists instead")
+        openlab_logger.warning("check_if_configuration_name_exists is Deprected. Use _check_if_configuration_name_exists instead")
         return self._check_if_configuration_name_exists(config_name)
 
     def _check_if_configuration_name_exists(self,config_name):
@@ -389,10 +389,10 @@ class http_client(object):
         self.standard_response(r, 204, model="simulation")
 
         if r.status_code == 204:
-            logger.info(f"Simulation {simulationID} was deleted")
+            openlab_logger.info(f"Simulation {simulationID} was deleted")
             return True
         else:            
-            logger.error(f"Unable to delete simulation {simulationID}")
+            openlab_logger.error(f"Unable to delete simulation {simulationID}")
             return False
 
     def delete_configuration(self, configurationID: str):
@@ -408,10 +408,10 @@ class http_client(object):
         self.standard_response(r, 204, model="configuration")
 
         if r.status_code == 204:
-            logger.info(f"Configuration {configurationID} and all its simulations were deleted")
+            openlab_logger.info(f"Configuration {configurationID} and all its simulations were deleted")
             return True
         else:
-            logger.error(f"Unable to delete configuration {configurationID}")
+            openlab_logger.error(f"Unable to delete configuration {configurationID}")
             return False
 
     def simulation_by_id(self, sim_id):
@@ -452,7 +452,7 @@ class http_client(object):
             * ManualReservoirMode, # bool. Default = False
         """
         if 'TimeStep' in kwargs.keys():
-            logger.warning('TimeStep has been deprecated in favor of more appropriate key name StepDuration')
+            openlab_logger.warning('TimeStep has been deprecated in favor of more appropriate key name StepDuration')
             kwargs['StepDuration'] = kwargs.get('TimeStep')
         
         # We set default influx_type here so we can derefence it and combine it with other kwargs
@@ -477,7 +477,7 @@ class http_client(object):
         if license_id is not None:
             kwargs['license_id'] = license_id
 
-        logger.info(f"User limits: {user_limits}")
+        openlab_logger.info(f"User limits: {user_limits}")
         # TODO: Do this in a better way (only on error) or remove it
         if type(user_limits) is dict and "MaxConcurrentSimulations" in user_limits.keys():
             simulation_capacity = user_limits['MaxConcurrentSimulations']
@@ -497,7 +497,7 @@ class http_client(object):
 
         # format the data to send web_client
         simulation= self.format_simulation_meta_data(self, sim_id, config_id, sim_name,initial_bit_depth, influx_type=influx_type, **kwargs)
-       
+        
         r=self.client.post(self.url+"/simulations", json = simulation)
         # Since post, no need to put model="simulation"
         r_json = self.standard_response(r, 200)
@@ -513,7 +513,7 @@ class http_client(object):
 
             status = r_json.get("Status")
             if status and status == "Running":
-                logger.info("Simulation Initialized")
+                openlab_logger.info("Simulation Initialized")
                 #create a simulation class and return it to the caller
                 return Simulation(config_id, simulation_id, self)
             else: 
@@ -591,14 +591,14 @@ class http_client(object):
 
             #check if influx id is one of the valid influx types
             if influx_type['Id'] in influx_ids:
-                logger.info(f"{influx_type['Id']} mode selected")
+                openlab_logger.info(f"{influx_type['Id']} mode selected")
                 for k in influx_type.keys():
                     #append model configuration with influx dict
                     model_configuration[k] = influx_type[k]
             else:
                 raise exceptions.ValidationError(f"Invalid influx id '{influx_type['Id']}' entered. Valid influx/loss Ids are {influx_ids}")                    
         elif kwargs.get('Id') == "ManualInflux" or kwargs.get('Id') == 'ManualLoss':
-            logger.info(f"{kwargs.get('Id')} selected")
+            openlab_logger.info(f"{kwargs.get('Id')} selected")
             keys = [
                 'ComplexReservoirKickOffTime', 'ManualInfluxLossMD',
                 'ManualInfluxLossMassRate','ManualInfluxLossTotalMass',
@@ -609,7 +609,7 @@ class http_client(object):
                 model_configuration[k] = kwargs[k]
             # TODO: Check ManualReservoirMode & UseReservoirModel to either throw exception or warn of atleast override if False
         else:
-            logger.info("No influx mode selected. Defaulting to 'NoInfluxLoss'")
+            openlab_logger.info("No influx mode selected. Defaulting to 'NoInfluxLoss'")
             model_configuration['Id'] = "NoInfluxLoss"
             model_configuration['ManualReservoirMode'] = False
             model_configuration['UseReservoirModel'] = False
@@ -623,7 +623,7 @@ class http_client(object):
         if kwargs.get('UseTransientMechanicalModel') is True:
             if step_duration != 0.1:
                 raise exceptions.ValidationError("When using Transient Mechanical Model. StepDuration must be 0.1")            
-            logger.info(f"Using Transient Mechanical Model with time step: {step_duration}")
+            openlab_logger.info(f"Using Transient Mechanical Model with time step: {step_duration}")
 
 
         model_configuration['StepDuration'] = step_duration
@@ -818,6 +818,15 @@ class Simulation(metaclass=IterSimulation):
             toSet["ControlActivePitDensity"] = self.setpoints.ControlActivePitDensity
         if self.setpoints.ControlActivePitTemperature is not None:
             toSet["ControlActivePitTemperature"] = self.setpoints.ControlActivePitTemperature
+        if self.setpoints.WOBAutoDriller is not None:
+            toSet["WOBAutoDriller"] = self.setpoints.WOBAutoDriller
+        if self.setpoints.DesiredWOB is not None:
+            toSet["DesiredWOB"] = self.setpoints.DesiredWOB
+        if self.setpoints.WOBProportionalGain is not None:
+            toSet["WOBProportionalGain"] = self.setpoints.WOBProportionalGain
+        if self.setpoints.WOBIntegralGain is not None:
+            toSet["WOBIntegralGain"] = self.setpoints.WOBIntegralGain    
+            
         return toSet
 
     def auto_step(self,steps: int, tags = None):
@@ -1018,7 +1027,7 @@ def stop_running_simulations():
     """
     number_of_sims = len(Simulation._registry)
     if number_of_sims > 0:
-        logger.info("Exiting Code...")
+        openlab_logger.info("Exiting Code...")
         try:
             #loop through all the client simulations
             for simulation in Simulation:
@@ -1030,11 +1039,11 @@ def stop_running_simulations():
                 already_ended = simulation.has_been_stopped
                 
                 if active and not already_ended:
-                    logger.info("Simulation {} is still {}".format(sim_id, status))
+                    openlab_logger.info("Simulation {} is still {}".format(sim_id, status))
                     if simulation.end_simulation_on_exiting == True:
                         simulation.stop()
                     else:
-                        logger.info("Sim {} was not ended because end_simulation_on_exiting was set to false".format(sim_id))
+                        openlab_logger.info("Sim {} was not ended because end_simulation_on_exiting was set to false".format(sim_id))
         except exceptions.SimulationNotFound:
             pass
 
