@@ -17,6 +17,7 @@ import time
 import inspect
 import urllib
 import keyring
+import tempfile
 
 #Get the location of the installed OpenLab Library
 current_directory = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
@@ -24,8 +25,6 @@ current_directory = os.path.dirname(os.path.abspath(inspect.getfile(inspect.curr
 #exec credentials to force compile so to recognize any changes to credentials
 exec(open(current_directory+"/credentials.py").read())
 
-token_file = "openlab_token.txt"
-token_path = os.path.join(current_directory, token_file)
 
 environments = {'prod': "https://live.openlab.app", 'dev' : "https://dev.openlab.app", 'build':"https://build.openlab.app", 'local':"http://localhost:8888"}
 valid_environments = environments.keys()
@@ -34,6 +33,12 @@ reference_username = 'current_user' # For storing the active username account
 
 logger = logger.makeLogger("openlab.login")
 
+# Get OS specific temporary folder location
+tmp_dir = tempfile.gettempdir()
+tmp_openlab_dir = os.path.join(tmp_dir, "openlab")
+token_file = "openlab_token.txt"
+token_path = os.path.join(tmp_openlab_dir, token_file)
+
 class OpenlabApplicationClient(Client):
     """
     Custom ApplicationClient based on oauthlib's WebApplicationClient in order to pass in custom grant type
@@ -64,25 +69,48 @@ def token_saver(token):
     Saves the token so it can be used next time
     """
     logger.info("Saving token")
+    
+    # Create the temporary openlab directory if it doesn't exist
+    if not os.path.isdir(tmp_openlab_dir):
+        os.makedirs(tmp_openlab_dir)
+    
     with open(token_path, 'w') as f:
         json.dump(token, f)
 
+def load_token():
+    """
+    Returns False if there is no temporary openlab folder
+    Returns False if there is no token file in that temporary openlab folder
+    Otherwise, it returns the token file, converted to dictionary object
+    """
+    # Check if there is a temporary openlab directory
+    if not os.path.isdir(tmp_openlab_dir):
+        return False
+
+    # Check if there is a token file in that temporary openlab directory
+    if not os.path.isfile(token_path):
+        return False
+
+    #open the token file and read it
+    token = open(token_path, 'r')
+    token_text = token.read()
+    #close the token file
+    token.close()
+
+    #convert the json data so that we can search key,value pairings
+    j = json.loads(token_text)
+    
+    return j
+
+
 def get_expire_time():
     """
     Returns the expire time of a token if one exists
     """
-    # check to see if a token exists
-    has_token = os.path.isfile(token_path)
+    # Load token
+    has_token = load_token()
     if has_token:
-         #open the token file and read it
-        token = open(token_path,'r')
-        token_text = token.read()
-        #close the token file
-        token.close()
-
-        #convert the json data so that we can search key,value pairings
-        j = json.loads(token_text)
-        return j['expires_at']
+        return has_token['expires_at']
     else:
         logger.warning("No token exists")
         return
