@@ -35,7 +35,7 @@ class Controler(object):
             self.error = self.reference - self.measured
             self.errorLast= self.reference - self.measuredLast
            
-        output = self.outputLast + (self.kp+self.ki*self.ts)*self.error-(self.kp-self.ki*self.ts/2)*self.errorLast
+        output = self.outputLast + (self.kp+self.ki*self.ts/2)*self.error-(self.kp-self.ki*self.ts/2)*self.errorLast
         
         if output > 1:
             output = 1
