@@ -8,7 +8,9 @@ def all_setpoints():
         "ChokeOpening", "FlowRateIn", "TopOfStringVelocity",
         "DesiredROP", "SurfaceRPM", "ChokePumpFlowRateIn", "BopChokeOpening",
         "MainPitActive", "MainPitReturn", "ControlActivePit",
-        "ControlActivePitDensity", "ControlActivePitTemperature"
+        "ControlActivePitDensity", "ControlActivePitTemperature",
+        "WOBAutoDriller", "DesiredWOB", "WOBProportionalGain",
+        "WOBIntegralGain"
     ]
     return empty_setpoints
 
@@ -16,7 +18,9 @@ valid_tags = [
         "ChokeOpening", "FlowRateIn", "TopOfStringVelocity",
         "DesiredROP", "SurfaceRPM", "ChokePumpFlowRateIn", "BopChokeOpening",
         "MainPitActive", "MainPitReturn", "ControlActivePit",
-        "ControlActivePitDensity", "ControlActivePitTemperature"
+        "ControlActivePitDensity", "ControlActivePitTemperature",
+        "WOBAutoDriller", "DesiredWOB", "WOBProportionalGain",
+        "WOBIntegralGain"
     ]
 
 class Setpoints():
@@ -36,6 +40,10 @@ class Setpoints():
         self.ControlActivePit = None #bool
         self.ControlActivePitDensity = None # float
         self.ControlActivePitTemperature = None # float
+        self.WOBAutoDriller = None # bool
+        self.DesiredWOB = None # float
+        self.WOBProportionalGain = None # float
+        self.WOBIntegralGain = None # float
     
     @property
     def ChokeOpening(self): return self.__ChokeOpening
@@ -96,3 +104,23 @@ class Setpoints():
     def ControlActivePitTemperature(self): return self.__ControlActivePitTemperature
     @ControlActivePitTemperature.setter
     def ControlActivePitTemperature(self, value): self.__ControlActivePitTemperature = value
+
+    @property
+    def WOBAutoDriller(self): return self.__WOBAutoDriller
+    @WOBAutoDriller.setter
+    def WOBAutoDriller(self, value): self.__WOBAutoDriller = value
+
+    @property
+    def DesiredWOB(self): return self.__DesiredWOB
+    @DesiredWOB.setter
+    def DesiredWOB(self, value): self.__DesiredWOB = value
+
+    @property
+    def WOBProportionalGain(self): return self.__WOBProportionalGain
+    @WOBProportionalGain.setter
+    def WOBProportionalGain(self, value): self.__WOBProportionalGain = value
+
+    @property
+    def WOBIntegralGain(self): return self.__WOBIntegralGain
+    @WOBIntegralGain.setter
+    def WOBIntegralGain(self, value): self.__WOBIntegralGain = value
